#!/usr/bin/env python
# vim: set ts=4 sts=4 sw=4 textwidth=92:

"""
Holds the ExtractFirstNewRAR class.

This module works with new-style rar sets which need to be extracted
before they are verified.

It will detect sets like the following:
X.par2
X.vol0+1.par2
...

X.part01.rar
X.part02.rar
...

Where the PAR2 files do not protect the rar files directly, but instead
protect the files contained inside the rar files.
"""

__author__    = "Ira W. Snyder (devel@irasnyder.com)"
__copyright__ = "Copyright (c) 2006,2007 Ira W. Snyder (devel@irasnyder.com)"
__license__   = "GNU GPL v2 (or, at your option, any later version)"

#    ExtractFirstNewRAR.py -- detect and work with a new-style rar set
#
#    Copyright (C) 2006,2007  Ira W. Snyder (devel@irasnyder.com)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import PAR2Set.ExtractFirstBase
import PAR2Set.NewRAR
import rsutil.common


def detector (name_files, prot_files):
	"""Detects a ExtractFirstNewRAR set"""

	return rsutil.common.has_a_match ('^.*\.part0*1\.rar$', name_files) \
			and not rsutil.common.has_a_match ('^.*\.part0*1\.rar$', prot_files)


class ExtractFirstNewRAR (PAR2Set.ExtractFirstBase.ExtractFirstBase, \
		PAR2Set.NewRAR.NewRAR):

	"""Class for new-style rar sets which must be extracted before repair"""

	def __repr__ (self):
		return 'EXTRACTFIRST NEWRAR'

