#!/usr/bin/env python
# vim: set ts=4 sts=4 sw=4 textwidth=92:

"""Holds the NewRAR class.

This is a new-style rar type.

It will detect sets like the following:
X.par2
X.vol0+1.par2
...

Y.part01.rar
Y.part02.rar
...

Where the PAR2 files protect the rar files directly. Y can (but is not required
to be) the same as X.
"""

__author__    = "Ira W. Snyder (devel@irasnyder.com)"
__copyright__ = "Copyright (c) 2006,2007 Ira W. Snyder (devel@irasnyder.com)"
__license__   = "GNU GPL v2 (or, at your option, any later version)"

#    NewRAR.py -- detect and work with a new-style rar set
#
#    Copyright (C) 2006,2007  Ira W. Snyder (devel@irasnyder.com)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os
import PAR2Set.Base
import rsutil.common


def detector (name_files, prot_files):
	"""Detector for the NewRAR type"""

	return rsutil.common.has_a_match ('^.*\.part0*1\.rar$', prot_files)


class NewRAR (PAR2Set.Base.Base):

	"""Class for new-style rar sets"""

	def __repr__ (self):
		return 'NEWRAR'

	def find_extraction_heads (self):
		"""Find the files to start extraction from. These end in '.part0*1.rar'"""

		return rsutil.common.find_matches ('^.*\.part0*1\.rar$', self.all_files)

	def extraction_function (self, file, todir):
		"""Extract a single rar file to the directory todir.

		   file -- the file to be extracted
		   todir -- the directory to extract into"""

		assert os.path.isfile (file)
		assert os.path.isdir (todir)

		RAR_CMD = rsutil.common.config_get_value ('commands', 'unrar')

		cmd = '%s \"%s\"' % (RAR_CMD, file)
		ret = rsutil.common.run_command (cmd, todir)

		# Check error code
		if ret != 0:
			return -rsutil.common.EEXTRACT

		return rsutil.common.SUCCESS

